import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { CommonCompModule } from '../../../../services/common.modules';
import { NzSelectModule } from 'ng-zorro-antd/select';
import { ReactiveFormsModule } from '@angular/forms';
import { NzRadioModule } from 'ng-zorro-antd/radio';
import { NzMessageService } from 'ng-zorro-antd/message';
import { NzGridModule } from 'ng-zorro-antd/grid';
import { NzCheckboxModule } from 'ng-zorro-antd/checkbox';
import { NzTableModule } from 'ng-zorro-antd/table';
import { NzModalService } from 'ng-zorro-antd/modal';
import {
  FormControl,
  FormGroup,
  NonNullableFormBuilder,
  Validators,
} from '@angular/forms';
interface author {
  name: string;
  unit: string;
  birth: Date | any;
  nationality: string;
  job: string;
  title: string;
  mobile: string;
  email: string;
  work: string;
}
interface achievementType {
  name: string;
  unit: string;
  date: Date | any;
}
@Component({
  selector: 'app-textbook-pertain',
  imports: [
    CommonCompModule,
    ReactiveFormsModule,
    NzSelectModule,
    NzRadioModule,
    NzGridModule,
    NzCheckboxModule,
    NzTableModule,
  ],
  standalone: true,
  templateUrl: './textbook-pertain.component.html',
  styleUrls: ['./textbook-pertain.component.scss'],
})
export class TextbookPertainComponent implements OnInit {
  @Input('editFrom') editFrom: any;
  @Input('maxWidth') maxWidth: number = 0;
  @Output() state: EventEmitter<any> = new EventEmitter<any>();
  @Output() save: EventEmitter<any> = new EventEmitter<any>();
  validateForm: FormGroup<{
    code: FormControl<string>; //适用专业代码及名称
    period: FormControl<number | any>; //课程学时
    lessons: FormControl<string>; //适用课程
    characteristic: FormControl<Array<any> | any>; //适用课程性质
    // authors: FormControl<Array<any> | any>; //作者信息
    authorDetails: FormControl<string>; //第一主编（作者）情况
    type: FormControl<string>; //申报类型
    // achievement: FormControl<Array<any> | any>; //相关科学研究项目、成果或论文专著（限5项）
  }> = this.fb.group({
    code: ['', [Validators.required]],
    period: ['', [Validators.required]],
    lessons: ['', [Validators.required]],
    characteristic: ['', [Validators.required]],
    // authors: ['', [Validators.required]],
    authorDetails: ['', [Validators.required]],
    type: ['', [Validators.required]],
    // achievement: ['', [Validators.required]],
  });
  //适用专业代码及名称
  selectList: Array<any> = [
    {
      name: '机械与工程',
      code: 'M001',
    },
    {
      name: '软件工程',
      code: 'M002',
    },
    {
      name: '生物工程学',
      code: 'M003',
    },
  ];
  //适用课程性质
  checkOptionsOne = [
    { label: '必修课', value: '必修课' },
    { label: '选修课', value: '选修课' },
    { label: '通识课', value: '通识课' },
    { label: '公共基础课', value: '公共基础课' },
    { label: '专业课', value: '专业课' },
    { label: '思想作者理论课', value: '思想作者理论课' },
    { label: '实验课', value: '实验课' },
  ];
  // checkOptionsTwo = [
  //   { label: '通识课', value: '通识课' },
  //   { label: '公共基础课', value: '公共基础课' },
  //   { label: '专业课', value: '专业课' },
  // ];
  // checkOptionsThree = [
  //   { label: '思想作者理论课', value: '思想作者理论课' },
  //   { label: '实验课', value: '实验课' },
  // ];
  //作者信息
  dataArr: Array<author> = [
    {
      name: '',
      unit: '',
      birth: '',
      nationality: '',
      job: '',
      title: '',
      mobile: '',
      email: '',
      work: '',
    },
  ];
  //相关科学研究项目、成果或论文专著（限5项）
  achievementOptions: Array<achievementType> = [
    {
      name: '',
      unit: '',
      date: '',
    },
  ];
  workOptions = ['主编', '作者', '副主编', '写者'];
  constructor(
    private fb: NonNullableFormBuilder,
    private modal: NzModalService,
    private msg: NzMessageService
  ) {}

  ngOnInit() {}
  submitForm(event?: string): void {
    console.log(this.validateForm.value);
    if (this.validateForm.valid) {
      console.log(this.validateForm.value);
    } else {
      Object.values(this.validateForm.controls).forEach((control) => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
      this.msg.warning('请填写完整信息');
    }
    if (event == 'pre') {
      this.state.emit('pre');
    }
    if (event == 'next') {
      this.state.emit('next');
    }
    if(event == 'complete')
    this.modal.success({
      nzTitle: '您已填写完成',
      nzContent: '<p>已保存并且至空间</p>',
      nzOnOk: () => console.log('Info OK')
    });
  }
  changeCode() {}
  getCode(e: any) {}

  //添加作者信息
  onPush(type: string, idx: number) {
    switch (type) {
      case 'dataArr':
        this.dataArr.splice(idx+1, 0, {
          name: '',
          unit: '',
          birth: '',
          nationality: '',
          job: '',
          title: '',
          mobile: '',
          email: '',
          work: '',
        });
        break;
      case 'achievementOptions':
        if (this.achievementOptions.length >= 5) {
          this.msg.warning('最多添加5条');
          return;
        }
        this.achievementOptions.splice(idx+1, 0, {
          name: '',
          unit: '',
          date: '',
        });
        break;
    }
  }
  //删除作者信息
  onDel(type: string, idx: number) {
    switch (type) {
      case 'dataArr':
        if (this.dataArr.length == 1) {
          this.dataArr = [
            {
              name: '',
              unit: '',
              birth: '',
              nationality: '',
              job: '',
              title: '',
              mobile: '',
              email: '',
              work: '',
            },
          ];
          return;
        }
        this.dataArr.splice(idx, 1);
        break;
      case 'achievementOptions':
        if (this.achievementOptions.length == 1) {
          this.achievementOptions = [
            {
              name: '',
              unit: '',
              date: '',
            },
          ];
          return;
        }
        this.achievementOptions.splice(idx, 1);
        break;
    }
  }
}
